==> 1.0.3.tar.gz: lib/paycaps_payment_screen.dart <==
part of paycaps;

class PayCapsPaymentScreen extends StatefulWidget {
  PayCapsRequest payCapsRequest;
  bool isCalled=false;

  PayCapsPaymentScreen({required this.payCapsRequest});

  @override
  _WebviewState createState() =>  _WebviewState();
}

class _WebviewState extends State<PayCapsPaymentScreen> {
  final GlobalKey webViewKey = GlobalKey();

  InAppWebViewController? webViewController;
  InAppWebViewGroupOptions options = InAppWebViewGroupOptions(
      crossPlatform: InAppWebViewOptions(
        supportZoom: true,
        useShouldOverrideUrlLoading: true,
        mediaPlaybackRequiresUserGesture: false,
        javaScriptEnabled: true,

      ),
      android: AndroidInAppWebViewOptions(
        useHybridComposition: true,
        builtInZoomControls: true,
        defaultTextEncodingName: "utf-8",
      ),
      ios: IOSInAppWebViewOptions(
        allowsInlineMediaPlayback: true,
      ));

  double progress = 0;

  var statusCode = 0;
  var message = "";
  var resultCode = 0;
  var amount = 0;
  var responseMessage = "";
  var appID = "";
  var transactionID = "";
  var transactionType = "";
  var orderID = "";
  var responseDateTime = "";
  var returnURL = "";

  @override
  void initState() {

    super.initState();
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return WillPopScope(
      onWillPop: () async {
        return true;
      },
      child:  Scaffold(
            body: SafeArea(
                child: Stack(
          children: [
            InAppWebView(

              key: webViewKey,
              initialOptions: options,
              initialUrlRequest: URLRequest(
                  url: Uri.parse(widget.payCapsRequest.pgURL),
                  method: 'POST',
                  body: Uint8List.fromList(utf8.encode(widget.payCapsRequest.getRequestParameter())),
                  headers: {'Content-Type': 'application/x-www-form-urlencoded'}),
              onWebViewCreated: (controller) {
                webViewController = controller;

              },
              onLoadStart: (controller, url) {},
              androidOnPermissionRequest: (controller, origin, resources) async {
                return PermissionRequestResponse(resources: resources, action: PermissionRequestResponseAction.GRANT);
              },
              shouldOverrideUrlLoading: (controller, navigationAction) async {
                var uri = navigationAction.request.url;

                return NavigationActionPolicy.ALLOW;
              },
              onLoadStop: (controller, url) async {},
              onLoadError: (controller, url, code, message) {},
              onProgressChanged: (controller, progress) {
                setState(() {
                  this.progress = progress / 100;
                });
                if (progress == 100) {
                  controller.getHtml().then((value) => {parseTheHTMLValue(value!)});
                }
              },
              onUpdateVisitedHistory: (controller, url, androidIsReload) {},
              onConsoleMessage: (controller, consoleMessage) {
                // print("consoleMessage = $consoleMessage");
              },
            ),
            progress < 1.0 ? LinearProgressIndicator(value: progress) : Container(),
          ],
        ))),
      );
  }

  parseTheHTMLValue(String value) {
    try {
      var document = parse(value);

      document.getElementsByTagName('input').forEach((element) {
        //take amount
        if (element.attributes['name'] == PayCapsConstant.RESPONSE_AMOUNT) {
          int number = int.parse(element.attributes['value']!);
          amount = number ~/ 100;
        }

        //take message
        if (element.attributes['name'] == PayCapsConstant.RESPONSE_MESSAGE) {
          message = element.attributes['value']!;
        }
        //take appid
        if (element.attributes['name'] == PayCapsConstant.RESPONSE_APP_ID) {
          appID = element.attributes['value']!;
        }
        //take transaction id
        if (element.attributes['name'] == PayCapsConstant.RESPONSE_TXN_ID) {
          transactionID = element.attributes['value']!;
        }
        //take transaction typed
        if (element.attributes['name'] == PayCapsConstant.RESPONSE_TXNTYPE) {
          transactionType = element.attributes['value']!;
        }

        //take transaction order id
        if (element.attributes['name'] == PayCapsConstant.RESPONSE_ORDER_ID) {
          orderID = element.attributes['value']!;
        }
        //take transaction return URL
        if (element.attributes['name'] == PayCapsConstant.RESPONSE_RETURN_URL) {
          returnURL = element.attributes['value']!;
        }

        //take response Date Time
        if (element.attributes['name'] == PayCapsConstant.RESPONSE_DATE_TIME) {
          responseDateTime = element.attributes['value']!;
        }
        //take response Date Time
        if (element.attributes['name'] == PayCapsConstant.RESPONSE_MESSAGE) {
          responseMessage = element.attributes['value']!;
        }
        //take payment status code
        if (element.attributes['name'] == PayCapsConstant.RESPONSE_CODE_STRING) {
          if (element.attributes['value'] == PayCapsConstant.PAYMENT_SUCCESS_CODE) {
            statusCode = PayCapsConstant.HTTP_SUCCESS_STATUS_CODE;
            message = PayCapsConstant.SUCCESS_MSG;
            // resultCode = Activity.RESULT_OK;
          } else {
            statusCode = PayCapsConstant.HTTP_FAILURE_STATUS_CODE;
            message = PayCapsConstant.FAILED_MSG;
            // resultCode = Activity.RESULT_OK;
          }
          setDelayResponse();
        }
      });
    } catch (e) {
      // print("html parse error = ${e}");
      statusCode = PayCapsConstant.HTTP_FAILURE_STATUS_CODE;
      message = PayCapsConstant.FAILED_MSG;
      setDelayResponse();
    }
  }

  void setDelayResponse() {

    debugPrint("call delay method");

    webViewController!.clearCache();
    webViewController!.clearFocus();
    webViewController!.clearMatches();

    Future.delayed(const Duration(seconds: 2)).then((value) {
      var paymentResponse = getPayCapsResponse();


      if(!widget.isCalled){
        widget.isCalled=true;
        Navigator.of(context,rootNavigator: true).pop(paymentResponse);
        debugPrint("call delay method 2 ");


      }
    });
  }

  PayCapsResponse getPayCapsResponse() {
    return PayCapsResponse(
        statusCode: statusCode,
        message: message,
        resultCode: resultCode,
        amount: amount,
        responseMessage: responseMessage,
        appID: appID,
        transactionID: transactionID,
        transactionType: transactionType,
        orderID: orderID,
        responseDateTime: responseDateTime,
        returnURL: returnURL);
  }
}

==> 1.0.4.tar.gz: lib/paycaps_payment_screen.dart <==
part of paycaps;

class PayCapsPaymentScreen extends StatefulWidget {
  PayCapsRequest payCapsRequest;
  bool isCalled=false;

  PayCapsPaymentScreen({required this.payCapsRequest});

  @override
  _WebviewState createState() =>  _WebviewState();
}

class _WebviewState extends State<PayCapsPaymentScreen> {
  final GlobalKey webViewKey = GlobalKey();

  InAppWebViewController? webViewController;
  InAppWebViewGroupOptions options = InAppWebViewGroupOptions(
      crossPlatform: InAppWebViewOptions(
        supportZoom: true,
        useShouldOverrideUrlLoading: true,
        mediaPlaybackRequiresUserGesture: false,
        javaScriptEnabled: true,

      ),
      android: AndroidInAppWebViewOptions(
        useHybridComposition: true,
        builtInZoomControls: true,
        defaultTextEncodingName: "utf-8",
      ),
      ios: IOSInAppWebViewOptions(
        allowsInlineMediaPlayback: true,
      ));

  double progress = 0;

  var statusCode = 0;
  var message = "";
  var resultCode = 0;
  var amount = 0;
  var responseMessage = "";
  var appID = "";
  var transactionID = "";
  var transactionType = "";
  var orderID = "";
  var responseDateTime = "";
  var returnURL = "";

  var cardNumber = "";
  var brand = "";
  var cardType = "";
  var nickName = "";

  @override
  void initState() {
    super.initState();
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return WillPopScope(
      onWillPop: () async {
        return true;
      },
      child:  Scaffold(
            body: SafeArea(
                child: Stack(
          children: [
            InAppWebView(

              key: webViewKey,
              initialOptions: options,
              initialUrlRequest: URLRequest(
                  url: Uri.parse(widget.payCapsRequest.pgURL),
                  method: 'POST',
                  body: Uint8List.fromList(utf8.encode(widget.payCapsRequest.getRequestParameter())),
                  headers: {'Content-Type': 'application/x-www-form-urlencoded'}),
              onWebViewCreated: (controller) {
                webViewController = controller;

              },
              onLoadStart: (controller, url) {},
              androidOnPermissionRequest: (controller, origin, resources) async {
                return PermissionRequestResponse(resources: resources, action: PermissionRequestResponseAction.GRANT);
              },
              shouldOverrideUrlLoading: (controller, navigationAction) async {
                var uri = navigationAction.request.url;

                return NavigationActionPolicy.ALLOW;
              },
              onLoadStop: (controller, url) async {},
              onLoadError: (controller, url, code, message) {},
              onProgressChanged: (controller, progress) {
                setState(() {
                  this.progress = progress / 100;
                });
                if (progress == 100) {
                  controller.getHtml().then((value) => {parseTheHTMLValue(value!)});
                }
              },
              onUpdateVisitedHistory: (controller, url, androidIsReload) {},
              onConsoleMessage: (controller, consoleMessage) {
                // print("consoleMessage = $consoleMessage");
              },
            ),
            progress < 1.0 ? LinearProgressIndicator(value: progress) : Container(),
          ],
        ))),
      );
  }

  parseTheHTMLValue(String value) {
    try {
      var document = parse(value);

      // print("html parse documentation $value");

      document.getElementsByTagName('input').forEach((element) {
        //take amount
        if (element.attributes['name'] == PayCapsConstant.RESPONSE_AMOUNT) {
          int number = int.parse(element.attributes['value']!);
          amount = number ~/ 100;
        }

        //take message
        if (element.attributes['name'] == PayCapsConstant.RESPONSE_MESSAGE) {
          message = element.attributes['value']!;
        }
        //take appid
        if (element.attributes['name'] == PayCapsConstant.RESPONSE_APP_ID) {
          appID = element.attributes['value']!;
        }
        //take transaction id
        if (element.attributes['name'] == PayCapsConstant.RESPONSE_TXN_ID) {
          transactionID = element.attributes['value']!;
        }
        //take transaction typed
        if (element.attributes['name'] == PayCapsConstant.RESPONSE_TXNTYPE) {
          transactionType = element.attributes['value']!;
        }

        //take transaction order id
        if (element.attributes['name'] == PayCapsConstant.RESPONSE_ORDER_ID) {
          orderID = element.attributes['value']!;
        }
        //take transaction return URL
        if (element.attributes['name'] == PayCapsConstant.RESPONSE_RETURN_URL) {
          returnURL = element.attributes['value']!;
        }

        //take response Date Time
        if (element.attributes['name'] == PayCapsConstant.RESPONSE_DATE_TIME) {
          responseDateTime = element.attributes['value']!;
        }
        //take response Date Time
        if (element.attributes['name'] == PayCapsConstant.RESPONSE_MESSAGE) {
          responseMessage = element.attributes['value']!;
        }

        //take card number
        if (element.attributes['name'] == PayCapsConstant.RESPONSE_CARD_NUMBER) {
          cardNumber = element.attributes['value']!;
        }

        //nick name
        if (element.attributes['name'] == PayCapsConstant.RESPONSE_NICK_NAME) {
          nickName = element.attributes['value']!;
        }
        //payment type
        if (element.attributes['name'] == PayCapsConstant.RESPONSE_PAYMENT_TYPE) {
          cardType = element.attributes['value']!;
        }
        //card type
        if (element.attributes['name'] == PayCapsConstant.CARD_TYPE) {
          brand = element.attributes['value']!;
        }

        //take payment status code
        if (element.attributes['name'] == PayCapsConstant.RESPONSE_CODE_STRING) {
          if (element.attributes['value'] == PayCapsConstant.PAYMENT_SUCCESS_CODE) {
            statusCode = PayCapsConstant.HTTP_SUCCESS_STATUS_CODE;
            message = PayCapsConstant.SUCCESS_MSG;
            // resultCode = Activity.RESULT_OK;
          } else {
            statusCode = PayCapsConstant.HTTP_FAILURE_STATUS_CODE;
            message = PayCapsConstant.FAILED_MSG;
            // resultCode = Activity.RESULT_OK;
          }
          setDelayResponse();
        }
      });
    } catch (e) {
      // print("html parse error = ${e}");
      statusCode = PayCapsConstant.HTTP_FAILURE_STATUS_CODE;
      message = PayCapsConstant.FAILED_MSG;
      setDelayResponse();
    }
  }

  void setDelayResponse() {

    debugPrint("call delay method");

    webViewController!.clearCache();
    webViewController!.clearFocus();
    webViewController!.clearMatches();

    Future.delayed(const Duration(seconds: 2)).then((value) {
      var paymentResponse = getPayCapsResponse();


      if(!widget.isCalled){
        widget.isCalled=true;
        Navigator.of(context,rootNavigator: true).pop(paymentResponse);
        debugPrint("call delay method 2 ");


      }
    });
  }

  PayCapsResponse getPayCapsResponse() {
    return PayCapsResponse(
        statusCode: statusCode,
        message: message,
        resultCode: resultCode,
        amount: amount,
        responseMessage: responseMessage,
        appID: appID,
        transactionID: transactionID,
        transactionType: transactionType,
        orderID: orderID,
        responseDateTime: responseDateTime,
        returnURL: returnURL,
        cardNumber: cardNumber,
        cardType: cardType,
        brand: brand,
        nickName: nickName);
  }
}
